import { Component, OnInit } from '@angular/core';
import {DeviceService} from '../../../services/device.service';
import {ADMIN_INFO_OBJECT} from '../../../services/local-storage.namespace';
import {LocalStorageService} from '../../../services/local-storage.service';
import {environment} from '../../../../environments/environment';
import {AgentService} from '../../../services/agent.service';
import {SalesmanService} from '../../../services/salesman.service';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';

@Component({
  selector: 'app-device-list',
  templateUrl: './device-list.component.html',
  styleUrls: ['./device-list.component.scss']
})
export class DeviceListComponent implements OnInit {
  // 角色类型 0：超级管理员  1：公司  2：代理商  3：业务员  4：商户  5：门店
  roleType: number;

  baseUrl = environment.baseUrl;

  loadingObject = {
    spinning: false,
    msg: '加载中'
  };

  dataObject: any = {};
  tableLoading = true;
  searchForm: FormGroup;
  pageNum: number;
  whereObject: any = {};

  checkedData = [];

  agentDataArray = [];
  allocationAgentModal = false;
  allocationAgentForm: FormGroup;

  salesmanDataArray = [];
  allocationSalesmanModal = false;
  allocationSalesmanForm: FormGroup;

  importDeviceErrorModal = false;
  importDeviceErrorData = [];

  BTN_IMPORT_DEVICE = false;
  BTN_DOWN_DEVICE = false;
  BTN_AGENT_ALLOCATION;
  BTN_SALESMAN_ALLOCATION;
  BTN_STORE_BIND;
  BTN_STORE_UNBIND;

  constructor(private modal: NzModalService,
              private message: NzMessageService,
              private salesmanService: SalesmanService,
              private agentService: AgentService,
              private deviceService: DeviceService,
              private store: LocalStorageService,
              private form: FormBuilder) {
    this.roleType = this.store.get(ADMIN_INFO_OBJECT)['secRole'].roleType;
  }

  ngOnInit(): void {
    this.BTN_IMPORT_DEVICE = this.store.isBtnCompetence('BTN_import_device');  // 导入设备 按钮权限
    this.BTN_DOWN_DEVICE = this.store.isBtnCompetence('BTN_down_device');  // 下载设备 按钮权限
    this.BTN_AGENT_ALLOCATION = this.store.isBtnCompetence('BTN_agent_allocation');  // 分配代理商 按钮权限
    this.BTN_SALESMAN_ALLOCATION = this.store.isBtnCompetence('BTN_salesman_allocation');  // 分配业务员 按钮权限
    this.BTN_STORE_BIND = this.store.isBtnCompetence('BTN_store_bind');  // 门店绑定 按钮权限
    this.BTN_STORE_UNBIND = this.store.isBtnCompetence('BTN_store_unbind');  // 门店解绑 按钮权限

    this.searchForm = this.form.group({
      agentName: [null],
      salesmanName: [null],
      merName: [null],
      storeName: [null],
      deviceSn: [null],
    });

    this.allocationAgentForm = this.form.group({
      agentId: [null, [Validators.required]],
    });
    this.agentService.queryAgentList({ status: 1, pageNum: 1, pageSize: 999 }, data => {
      if (data['return_code'] === '000000') {
        this.agentDataArray = data['return_data']['list'];
      }
    });

    this.allocationSalesmanForm = this.form.group({
      salesmanId: [null, [Validators.required]],
    });
    this.salesmanService.querySalesmanListByAgent({ status: 1, pageNum: 1, pageSize: 999 }, data => {
      if (data['return_code'] === '000000') {
        this.salesmanDataArray = data['return_data']['list'];
      }
    });

    this.requestData(1);
  }

  /**
   * 请求数据
   */
  requestData(pageNum) {
    this.tableLoading = true;
    this.whereObject['pageNum'] = pageNum;
    this.whereObject['pageSize'] = 10;
    this.deviceService.getDeviceList(this.whereObject, data => {
      if (data['return_code'] === '000000') {
        this.dataObject = data['return_data'];
      } else {
        this.modal.error(data['return_msg']);
      }
      this.tableLoading = false;
    });
  }

  /**
   * 搜索
   * @param whereObject 条件
   */
  search(whereObject: object) {
    this.whereObject = whereObject;
    this.requestData(1);
  }

  /**
   * 重置
   */
  resetForm(): void {
    this.searchForm.reset();
  }

  /**
   * 弹出删除对话框
   */
  showDeleteConfirm(data: object): void {
    this.modal.confirm({
      nzTitle: '警告',
      nzContent: '是否删除该设备',
      nzOkText: '是',
      nzCancelText: '否',
      nzOkType: 'danger',
      nzOnOk: () => this.deleteData(data['id'])
    });
  }

  /**
   * 删除数据
   *
   */
  deleteData(id: number) {
    this.deviceService.delDevice({ deviceId : id}, data => {
      if (data['return_code'] === '000000') {
        this.requestData(this.whereObject['pageNum']);
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg']
        });
      }
    });
  }

  /**
   * 下载导入设备模板
   */
  downloadDeviceTemplate() {
    window.location.href = environment.imageUrl + '/设备导入模板.xlsx';
  }

  /**
   * 导入设备回调
   * @param fileInfo
   */
  importDeviceChange(fileInfo) {
    this.loadingObject.spinning = true;
    this.loadingObject.msg = '设备导入中...';
    if (fileInfo.file.status !== 'uploading') {

    }

    if (fileInfo.file.status === 'done') {
      if (fileInfo.file.response.return_code === '000000') {
        this.loadingObject.spinning = false;
        if (fileInfo.file.response.return_data == null || fileInfo.file.response.return_data.length === 0) {
          this.modal.success({
            nzTitle: '提示',
            nzContent: '成功',
            nzOnOk: () => this.requestData(1)
          });
        } else {
          console.log(fileInfo.file.response.return_data);
          this.modal.warning({
            nzTitle: '提示',
            nzOkText: '导入失败数据',
            nzContent: '只有部分数据导入成功',
            nzOnOk: () => this.showDeviceErrorModal(fileInfo.file.response.return_data)
          });
        }
      } else {
        this.loadingObject.spinning = false;
        this.modal.error({
          nzTitle: '提示',
          nzContent: fileInfo.file.response.return_msg,
        });
      }
    } else if (fileInfo.file.status === 'error') {
      this.loadingObject.spinning = false;
      this.modal.error({
        nzTitle: '提示',
        nzContent: '导入失败'
      });
    }
  }

  /**
   * 打开模态框
   */
  showDeviceErrorModal(data: []) {
    this.requestData(this.whereObject['pageNum']);
    this.importDeviceErrorData = data;
    this.importDeviceErrorModal = true;
  }

  /**
   * 关闭模态框
   */
  handleCancel() {
    this.importDeviceErrorModal = false;
  }

  /**
   * 弹出分配代理商模态框
   */
  showUnbindStore(deviceId: number): void {
    this.modal.confirm({
      nzTitle: '警告',
      nzContent: '是否解绑该设备，会影响门店使用',
      nzOkText: '是',
      nzCancelText: '否',
      nzOkType: 'danger',
      nzOnOk: () => this.unbindStore(deviceId)
    });
  }

  /**
   * 门店解绑
   */
  unbindStore(id: number) {
    this.deviceService.unbindStore({ deviceId: id}, data => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '解绑成功',
        });
        this.requestData(this.whereObject['pageNum']);
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
    });
  }

  /**
   * 弹出分配代理商模态框
   */
  showAllocationAgentModal() {
    this.allocationAgentModal = true;
  }

  /**
   * 关闭分配代理商模态框
   */
  closeAllocationAgentModal() {
    this.allocationAgentModal = false;
  }

  /**
   * 提交代理商
   */
  submitAllocationAgent() {
    for (const i in this.allocationAgentForm.controls) {
      this.allocationAgentForm.controls[i].markAsDirty();
      this.allocationAgentForm.controls[i].updateValueAndValidity();
    }
    if (this.allocationAgentForm.status == null || this.allocationAgentForm.status !== 'VALID') {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请选择代理商',
      });
      return;
    }
    if (this.checkedData.length === 0) {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请选择需要分配的设备',
      });
      return;
    }
    this.allocationAgentForm.value['deviceArray'] = this.checkedData;
    this.deviceService.assignAgent(this.allocationAgentForm.value, data => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '分配成功',
        });
        this.checkedData = [];
        this.requestData(this.whereObject['pageNum']);
        this.closeAllocationAgentModal();
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
    });

  }

  /**
   * 弹出分配业务员模态框
   */
  showAllocationSalesmanModal() {
    this.allocationSalesmanModal = true;
  }

  /**
   * 关闭分配业务员模态框
   */
  closeAllocationSalesmanModal() {
    this.allocationSalesmanModal = false;
  }

  /**
   * 提交代理商
   */
  submitAllocationSalesman() {
    for (const i in this.allocationSalesmanForm.controls) {
      this.allocationSalesmanForm.controls[i].markAsDirty();
      this.allocationSalesmanForm.controls[i].updateValueAndValidity();
    }
    if (this.allocationSalesmanForm.status == null || this.allocationSalesmanForm.status !== 'VALID') {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请选择业务员',
      });
      return;
    }
    if (this.checkedData.length === 0) {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请选择需要分配的设备',
      });
      return;
    }
    this.allocationSalesmanForm.value['deviceArray'] = this.checkedData;
    this.deviceService.assignSalesman(this.allocationSalesmanForm.value, data => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '分配成功',
        });
        this.checkedData = [];
        this.requestData(this.whereObject['pageNum']);
        this.closeAllocationSalesmanModal();
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
    });

  }

  /**
   * 选中
   * @param data
   * @param checked
   */
  checkedChange(data: object, checked: boolean) {
    if (checked === true) {
      data['checked'] = true;
      this.checkedData.push(data);
    } else {
      data['checked'] = true;
      const findIndex = this.checkedData.findIndex(o => Number(o['id']) === Number(data['id']));
      this.checkedData.splice(findIndex, 1);
    }
  }

}
